==> automated-cloud-advisor-1.1.5.tgz: package/README.md <==
<h1 align="center">Automated-Cloud-Advisor</h1>
<!-- Logo -->
<p align="center">
    <img width="200px"  src="https://github.com/disneystreaming/automated-cloud-advisor/raw/master/website/static/img/logo.svg" alt="Logo">
</p>
<!-- Install -->
<h2 align="center">
  👉 <a target="_blank" href="https://disneystreaming.github.io/automated-cloud-advisor/">Installation</a> 👈
</h2>
<!-- Repo -->
<p align="center">
  <a href="https://GitHub.com/disneystreaming/automated-cloud-advisor/issues/">
    <img alt="Issues" src="https://img.shields.io/github/issues/disneystreaming/automated-cloud-advisor.svg">
  </a>
  <a href="https://GitHub.com/disneystreaming/automated-cloud-advisor/pull/">
    <img alt="Pull Requests" src="https://img.shields.io/github/issues-pr/disneystreaming/automated-cloud-advisor.svg">
</p>
<!-- Workflow -->
<p align="center">
  <a href="https://github.com/disneystreaming/automated-cloud-advisor/actions?query=workflow%3ABuild">
    <img alt="Build" src="https://github.com/disneystreaming/automated-cloud-advisor/workflows/Build/badge.svg">
  </a>
  <a href="https://github.com/disneystreaming/automated-cloud-advisor/actions?query=workflow%3ADocs">
    <img alt="Docs" src="https://github.com/disneystreaming/automated-cloud-advisor/workflows/Docs/badge.svg">
  </a>
  <a href="https://github.com/disneystreaming/automated-cloud-advisor/actions?query=workflow%3APublish">
    <img alt="Docs" src="https://github.com/disneystreaming/automated-cloud-advisor/workflows/Publish/badge.svg">
  </a>
</p>
<!-- NPM -->
<p align="center">
  <a href="https://www.npmjs.com/package/automated-cloud-advisor">
    <img alt="npm latest version" src="https://img.shields.io/npm/v/automated-cloud-advisor">
  </a>
  <a href="https://www.npmjs.com/package/automated-cloud-advisor">
    <img alt="dependencies Status" src="https://img.shields.io/david/disneystreaming/automated-cloud-advisor">
  </a>
  <a href="https://www.npmjs.com/package/automated-cloud-advisor">
    <img alt="devDependencies Status" src="https://img.shields.io/david/dev/disneystreaming/automated-cloud-advisor?label=devDependencies">
  </a>
</p>
<!-- License -->
<p align="center">
  <a href="https://github.com/semantic-release/semantic-release">
    <img alt="semantic-release" src="https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg">
  </a>
  <a href="https://opensource.org/licenses/Apache-2.0">
    <img alt="License" src="https://img.shields.io/badge/License-Apache%202.0-blue.svg">
  </a>
  <a href="https://cla-assistant.io/disneystreaming/automated-cloud-advisor">
    <img alt="CLA assistant" src="https://cla-assistant.io/readme/badge/disneystreaming/automated-cloud-advisor">
  </a>
    <a href="https://gitter.im/disneystreaming/automated-cloud-advisor">
    <img alt="Join the chat at https://gitter.im/disneystreaming/automated-cloud-advisor" src="https://badges.gitter.im/Join%20Chat.svg">
  </a>
</p>
<!-- Code Quality -->
<p align="center">
  <a href="https://snyk.io/test/github/disneystreaming/automated-cloud-advisor?targetFile=package.json">
    <img src="https://snyk.io/test/github/disneystreaming/automated-cloud-advisor/badge.svg?targetFile=package.json" alt="Known Vulnerabilities">
  </a>
  <a href="https://sonarcloud.io/dashboard?id=disneystreaming_automated-cloud-advisor">
    <img alt="Sonar Quality" src="https://sonarcloud.io/api/project_badges/measure?project=disneystreaming_automated-cloud-advisor&metric=alert_status">
  </a>
<a href="https://codecov.io/gh/disneystreaming/automated-cloud-advisor">
  <img src="https://codecov.io/gh/disneystreaming/automated-cloud-advisor/branch/master/graph/badge.svg" />
</a>
  <a href="http://standardjs.com">
    <img alt="js-standard-style" src="https://img.shields.io/badge/code%20style-standard-brightgreen.svg">
  </a>
</p>

<h2 align="center">💬 Motivation 💬</h2>

<p align="center">
  Automated Cloud Advisor is a extensible tool that aims at facilitating cost optimization in AWS, by collecting data for resources that are under utilized. In addition, this is a great learning tool for new DevOps/Cloud engineers that want to start automating things in AWS.
  </br></br>
  The tool is deployed as a set of cloudformation stacks that comprise the data collection and the data can be displayed in a Kibana dashboard.
</p>
<!-- Diagrams -->
<p align="center">
    <img src="https://disneystreaming.github.io/automated-cloud-advisor/img/trusted_advisor.png" alt="Refresh">
</p>

<p align="center">
    <img src="https://disneystreaming.github.io/automated-cloud-advisor/img/index_data.png" alt="Index">
</p>

<p align="center">
    <img src="https://disneystreaming.github.io/automated-cloud-advisor/img/view_data.png" alt="Stream">
</p>
<!-- Dashboard -->
<p align="center">
    <img src="https://disneystreaming.github.io/automated-cloud-advisor/img/kibana/dashboard/01-dashboard.png" alt="Dashboard">
</p>

<h2 align="center">💻 Installation 💻</h2>

<p align="center">
  <a href="https://disneystreaming.github.io/automated-cloud-advisor/">Get Started</a>
</p>

<h2 align="center">📛 Uninstall 📛</h2>

<p align="center">
  Delete Stack with the AWS Console/CLI
</p>

<h2 align="center">🎁 Contribute 🎁</h2>

<p align="center">
  Sign the  <a href="https://disneystreaming.github.io/automated-cloud-advisor/">CLA</a>
  </br>
  Submit pull request to the master branch
</p>

<h2 align="center">📈 Coding Standards 📈</h2>

<p align="center">
  Documentation
  </br>
  Up to date dependencies
  </br>
  Passing lint with standard coding style
  </br>
  Passing unit tests with 100% coverage
  </br>
</p>

<h2 align="center">📅 Maintenance Plan 📅</h2>

<p align="center">
  Submit pull request
  </br>
  Merge pull request to master
  </br>
  <a href="https://github.com/semantic-release/semantic-release">Semantic Release</a> will publish a new version
</p>

==> automated-cloud-advisor-1.1.6.tgz: package/README.md <==
<h1 align="center">Automated-Cloud-Advisor</h1>
<!-- Logo -->
<p align="center">
    <img width="200px"  src="https://github.com/disneystreaming/automated-cloud-advisor/raw/master/website/static/img/logo.svg" alt="Logo">
</p>
<!-- Install -->
<h2 align="center">
  👉 <a target="_blank" href="https://disneystreaming.github.io/automated-cloud-advisor/">Installation</a> 👈
</h2>
<!-- Repo -->
<p align="center">
  <a href="https://GitHub.com/disneystreaming/automated-cloud-advisor/issues/">
    <img alt="Issues" src="https://img.shields.io/github/issues/disneystreaming/automated-cloud-advisor.svg">
  </a>
  <a href="https://GitHub.com/disneystreaming/automated-cloud-advisor/pull/">
    <img alt="Pull Requests" src="https://img.shields.io/github/issues-pr/disneystreaming/automated-cloud-advisor.svg">
</p>
<!-- Workflow -->
<p align="center">
  <a href="https://github.com/disneystreaming/automated-cloud-advisor/actions?query=workflow%3ABuild">
    <img alt="Build" src="https://github.com/disneystreaming/automated-cloud-advisor/workflows/Build/badge.svg">
  </a>
  <a href="https://github.com/disneystreaming/automated-cloud-advisor/actions?query=workflow%3ADocs">
    <img alt="Docs" src="https://github.com/disneystreaming/automated-cloud-advisor/workflows/Docs/badge.svg">
  </a>
  <a href="https://github.com/disneystreaming/automated-cloud-advisor/actions?query=workflow%3APublish">
    <img alt="Docs" src="https://github.com/disneystreaming/automated-cloud-advisor/workflows/Publish/badge.svg">
  </a>
</p>
<!-- NPM -->
<p align="center">
  <a href="https://www.npmjs.com/package/automated-cloud-advisor">
    <img alt="npm latest version" src="https://img.shields.io/npm/v/automated-cloud-advisor">
  </a>
  <a href="https://www.npmjs.com/package/automated-cloud-advisor">
    <img alt="dependencies Status" src="https://img.shields.io/david/disneystreaming/automated-cloud-advisor">
  </a>
  <a href="https://www.npmjs.com/package/automated-cloud-advisor">
    <img alt="devDependencies Status" src="https://img.shields.io/david/dev/disneystreaming/automated-cloud-advisor?label=devDependencies">
  </a>
</p>
<!-- License -->
<p align="center">
  <a href="https://github.com/semantic-release/semantic-release">
    <img alt="semantic-release" src="https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg">
  </a>
  <a href="https://opensource.org/licenses/Apache-2.0">
    <img alt="License" src="https://img.shields.io/badge/License-Apache%202.0-blue.svg">
  </a>
  <a href="https://cla-assistant.io/disneystreaming/automated-cloud-advisor">
    <img alt="CLA assistant" src="https://cla-assistant.io/readme/badge/disneystreaming/automated-cloud-advisor">
  </a>
    <a href="https://gitter.im/disneystreaming/automated-cloud-advisor">
    <img alt="Join the chat at https://gitter.im/disneystreaming/automated-cloud-advisor" src="https://badges.gitter.im/Join%20Chat.svg">
  </a>
</p>
<!-- Code Quality -->
<p align="center">
  <a href="https://snyk.io/test/github/disneystreaming/automated-cloud-advisor?targetFile=package.json">
    <img src="https://snyk.io/test/github/disneystreaming/automated-cloud-advisor/badge.svg?targetFile=package.json" alt="Known Vulnerabilities">
  </a>
  <a href="https://sonarcloud.io/dashboard?id=disneystreaming_automated-cloud-advisor">
    <img alt="Sonar Quality" src="https://sonarcloud.io/api/project_badges/measure?project=disneystreaming_automated-cloud-advisor&metric=alert_status">
  </a>
<a href="https://codecov.io/gh/disneystreaming/automated-cloud-advisor">
  <img src="https://codecov.io/gh/disneystreaming/automated-cloud-advisor/branch/master/graph/badge.svg" />
</a>
  <a href="http://standardjs.com">
    <img alt="js-standard-style" src="https://img.shields.io/badge/code%20style-standard-brightgreen.svg">
  </a>
</p>

<h2 align="center">💬 Motivation 💬</h2>

<p align="center">
  Automated Cloud Advisor is a extensible tool that aims at facilitating cost optimization in AWS, by collecting data for resources that are under utilized. In addition, this is a great learning tool for new DevOps/Cloud engineers that want to start automating things in AWS.
  </br></br>
  The tool is deployed as a set of cloudformation stacks that comprise the data collection and the data can be displayed in a Kibana dashboard.
</p>
<!-- Diagrams -->
<p align="center">
    <img src="https://disneystreaming.github.io/automated-cloud-advisor/img/trusted_advisor.png" alt="Refresh">
</p>

<p align="center">
    <img src="https://disneystreaming.github.io/automated-cloud-advisor/img/index_data.png" alt="Index">
</p>

<p align="center">
    <img src="https://disneystreaming.github.io/automated-cloud-advisor/img/view_data.png" alt="Stream">
</p>
<!-- Dashboard -->
<p align="center">
    <img src="https://disneystreaming.github.io/automated-cloud-advisor/img/kibana/dashboard/01-dashboard.png" alt="Dashboard">
</p>

<h2 align="center">💻 Installation 💻</h2>

<p align="center">
  <a href="https://disneystreaming.github.io/automated-cloud-advisor/">Get Started</a>
</p>

<h2 align="center">📛 Uninstall 📛</h2>

<p align="center">
  Delete Stack with the AWS Console/CLI
</p>

<h2 align="center">🎁 Contribute 🎁</h2>

<p align="center">
  Sign the  <a href="https://disneystreaming.github.io/automated-cloud-advisor/">CLA</a>
  </br>
  Submit pull request to the main branch
</p>

<h2 align="center">📈 Coding Standards 📈</h2>

<p align="center">
  Documentation
  </br>
  Up to date dependencies
  </br>
  Passing lint with standard coding style
  </br>
  Passing unit tests with 100% coverage
  </br>
</p>

<h2 align="center">📅 Maintenance Plan 📅</h2>

<p align="center">
  Submit pull request
  </br>
  Merge pull request to the main branch
  </br>
  <a href="https://github.com/semantic-release/semantic-release">Semantic Release</a> will publish a new version
</p>
